@@ -6,7 +6,7 @@ from django import template
 from django.utils.safestring import mark_safe
 from django.core.cache import cache
 
-from sveedocuments.settings_local import DOCUMENTS_PAGE_TREEMENU, DOCUMENTS_PAGE_FLATMENU
+from sveedocuments.local_settings import DOCUMENTS_PAGE_TREEMENU, DOCUMENTS_PAGE_FLATMENU
 from sveedocuments.models import Insert, Page
 from sveedocuments.templatetags import get_render_with_cache, get_toc_with_cache
 from sveedocuments.utils.templatetags import resolve_string_or_variable
